# HasAttrs

A pure python package used to check if objects have the same attrs as
collections.abc types.

## Description

Use HasAttrs to check if you objects have the same attributes as the
classes in collections.abs, such as Mapping and MutableSequence.
HasAttrs has no dependencies outside Python.

## Getting Started

### Dependencies

* Python>=3.6

### Installing

* pip install hasattrs

### Executing program

* How to run the program
* Step-by-step bullets
```
Example code to come.
```

## Authors

Contributors names and contact info

Odos Matthews: odosmatthews@gmail.com

## License

This project is licensed under the MIT License - see the LICENSE.md file for details